@@ -30,7 +30,7 @@ def save(
     save_images(tf_img, out_path)
 
 
-def show_me_a(
+def show_me(
     prompt,
     batch_size: int = 1,
     guidance_scale: float = 3.0,
